@@ -4,20 +4,12 @@
  *
  * Implementation of the HoeffdingTree class.
  *
- * This file is part of mlpack 2.0.0.
+ * This file is part of mlpack 2.0.1.
  *
- * mlpack is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * mlpack is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * mlpack.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_IMPL_HPP
 #define __MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_IMPL_HPP
@@ -198,6 +190,8 @@ HoeffdingTree<FitnessFunction, NumericSplitType, CategoricalSplitType>::
     delete dimensionMappings;
   if (ownsInfo)
     delete datasetInfo;
+  for (size_t i = 0; i < children.size(); ++i)
+    delete children[i];
 }
 
 //! Train on a set of points.
@@ -424,6 +418,70 @@ size_t HoeffdingTree<
   }
 }
 
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::SuccessProbability(const double successProbability)
+{
+  this->successProbability = successProbability;
+  for (size_t i = 0; i < children.size(); ++i)
+    children[i]->SuccessProbability(successProbability);
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::MinSamples(const size_t minSamples)
+{
+  this->minSamples = minSamples;
+  for (size_t i = 0; i < children.size(); ++i)
+    children[i]->MinSamples(minSamples);
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::MaxSamples(const size_t maxSamples)
+{
+  this->maxSamples = maxSamples;
+  for (size_t i = 0; i < children.size(); ++i)
+    children[i]->MaxSamples(maxSamples);
+}
+
+template<
+    typename FitnessFunction,
+    template<typename> class NumericSplitType,
+    template<typename> class CategoricalSplitType
+>
+void HoeffdingTree<
+    FitnessFunction,
+    NumericSplitType,
+    CategoricalSplitType
+>::CheckInterval(const size_t checkInterval)
+{
+  this->checkInterval = checkInterval;
+  for (size_t i = 0; i < children.size(); ++i)
+    children[i]->CheckInterval(checkInterval);
+}
+
 template<
     typename FitnessFunction,
     template<typename> class NumericSplitType,
@@ -618,8 +676,12 @@ void HoeffdingTree<
   using data::CreateNVP;
 
   ar & CreateNVP(splitDimension, "splitDimension");
+
+  // Clear memory for the mappings if necessary.
+  if (Archive::is_loading::value && ownsMappings && dimensionMappings)
+    delete dimensionMappings;
+
   ar & CreateNVP(dimensionMappings, "dimensionMappings");
-  ar & CreateNVP(ownsMappings, "ownsMappings");
 
   // Special handling for const object.
   data::DatasetInfo* d = NULL;
@@ -628,8 +690,17 @@ void HoeffdingTree<
   ar & CreateNVP(d, "datasetInfo");
   if (Archive::is_loading::value)
   {
+    if (datasetInfo && ownsInfo)
+      delete datasetInfo;
+
     datasetInfo = d;
     ownsInfo = true;
+    ownsMappings = true; // We also own the mappings we loaded.
+
+    // Clear the children.
+    for (size_t i = 0; i < children.size(); ++i)
+      delete children[i];
+    children.clear();
   }
 
   ar & CreateNVP(majorityClass, "majorityClass");
@@ -703,13 +774,22 @@ void HoeffdingTree<
       numChildren = children.size();
     ar & CreateNVP(numChildren, "numChildren");
     if (Archive::is_loading::value) // If needed, allocate space.
-      children.resize(numChildren, new HoeffdingTree(data::DatasetInfo(0), 0));
+    {
+      children.resize(numChildren, NULL);
+      for (size_t i = 0; i < numChildren; ++i)
+        children[i] = new HoeffdingTree(data::DatasetInfo(0), 0);
+    }
 
     for (size_t i = 0; i < numChildren; ++i)
     {
       std::ostringstream name;
       name << "child" << i;
       ar & data::CreateNVP(*children[i], name.str());
+
+      // The child doesn't actually own its own DatasetInfo.  We do.  The same
+      // applies for the dimension mappings.
+      children[i]->ownsInfo = false;
+      children[i]->ownsMappings = false;
     }
 
     if (Archive::is_loading::value)
