@@ -4,20 +4,12 @@
  *
  * A command-line executable that can build a streaming decision tree.
  *
- * This file is part of mlpack 2.0.0.
+ * This file is part of mlpack 2.0.1.
  *
- * mlpack is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * mlpack is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * mlpack.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
 #include <mlpack/methods/hoeffding_trees/hoeffding_tree.hpp>
@@ -336,7 +328,7 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
 
   // Check the accuracy on the training set.
   if (!outputModelFile.empty())
-    data::Save(outputModelFile, "streamingDecisionTree", tree, true);
+    data::Save(outputModelFile, "streamingDecisionTree", *tree, true);
 
   // Clean up memory.
   delete tree;
