@@ -3,20 +3,12 @@
  *
  * Test file for AllkNN class.
  *
- * This file is part of mlpack 2.0.0.
+ * This file is part of mlpack 2.0.1.
  *
- * mlpack is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * mlpack is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * mlpack.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
 #include <mlpack/methods/neighbor_search/neighbor_search.hpp>
@@ -321,7 +313,7 @@ BOOST_AUTO_TEST_CASE(MoveConstructorTest)
   for (size_t i = 0; i < moveDistances.n_elem; ++i)
   {
     BOOST_REQUIRE_EQUAL(moveNeighbors[i], neighbors[i]);
-    if (std::abs(distances[i] < 1e-5))
+    if (std::abs(distances[i]) < 1e-5)
       BOOST_REQUIRE_SMALL(moveDistances[i], 1e-5);
     else
       BOOST_REQUIRE_CLOSE(moveDistances[i], distances[i], 1e-5);
